==> deepin-screen-recorder_5.8.1.orig.tar.xz: deepin-screen-recorder-5.8.1/translations/deepin-screen-recorder_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Kliknij ikonę zasobnika 
lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Nagraj</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Zrzut ekranu</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Zrzut ekranu</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Zapisywanie nie powiodło się. Proszę zapisać go w swoim katalogu domowym.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Widok</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Zrzut ekranu zakończony</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>wybierz obszar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Zapisano w %1</translation>
    </message>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Przechwytywanie ekranu rozpocznie się za %1 sekund</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignoruj</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Schowek</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Zapisywanie pliku nagrania ekranu, proszę czekać...</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Wyjście</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>Screen Capture</source>
        <translation>Zrzut ekranu</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Podgląd</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Nagrywanie zakończone</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Zapisano w %1</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Przechwytywanie ekranu rozpocznie się za %1 sekund</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Wpisz tekst tutaj</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Start/Zrzut ekranu</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Wyjście/Zapisz</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Rysowanie</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Regulacja rozmiaru</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Szybki start</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Zrzut ekranu okna</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Opóźnij zrzut ekranu</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Pełny zrzut ekranu</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Pełny zrzut ekranu</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Wyjście</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Prostokąt</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linia</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Ołówek</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Zwiększ wysokość</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Zwiększ wysokość w dół</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Zwiększ szerokość w lewo</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Zwiększ szerokość w prawo</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Zmniejsz wysokość w górę</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Zmniejsz wysokość w dół</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Zmniejsz szerokość w lewo</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Zmniejsz szerokość w prawo</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Wyświetl skróty</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Rozmaż</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mozaika</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Włącz dźwięk</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>System audio</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Wyłącz dźwięk</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Pokaż naciśnięcie klawisza</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Ukryj naciśnięcie klawisza</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Włącz kamerę</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Wyłącz kamerę</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Pokaż kliknięcie</translation>
    </message>
    <message>
        <source>Hide Click</source>
        <translation>Ukryj kliknięcie</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcję</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Prostokąt</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linia</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Strzałka</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Ołówek</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Zapisz do</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Pulpit</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Zdjęcia</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Folder</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Schowek</translation>
    </message>
    <message>
        <source>Edit in Draw</source>
        <translation>Edytuj w Draw</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Pokaż wskaźnik</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Nagrania</translation>
    </message>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Nagrywanie ekranu nie jest obecnie obsługiwane</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Wyjście</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.9.3.orig.tar.xz: deepin-screen-recorder-5.9.3/translations/deepin-screen-recorder_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Kliknij ikonę zasobnika 
lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Nagraj</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Zrzut ekranu</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Zrzut ekranu</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Zapisywanie nie powiodło się. Proszę zapisać go w swoim katalogu domowym.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Widok</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Zrzut ekranu zakończony</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>wybierz obszar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Zapisano w %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignoruj</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Schowek</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Zapisywanie pliku nagrania ekranu, proszę czekać...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Zrzut ekranu</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Wyjście</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Podgląd</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Nagrywanie zakończone</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Zapisano w %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Nagraj</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Przechwytywanie ekranu rozpocznie się za %1 sekund</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Wpisz tekst tutaj</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Start/Zrzut ekranu</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Wyjście/Zapisz</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Rysowanie</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Regulacja rozmiaru</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Szybki start</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Zrzut ekranu okna</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Opóźnij zrzut ekranu</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Pełny zrzut ekranu</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Wyjście</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Prostokąt</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linia</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Ołówek</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Zwiększ wysokość</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Zwiększ wysokość w dół</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Zwiększ szerokość w lewo</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Zwiększ szerokość w prawo</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Zmniejsz wysokość w górę</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Zmniejsz wysokość w dół</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Zmniejsz szerokość w lewo</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Zmniejsz szerokość w prawo</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Wyświetl skróty</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keystroke</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Rozpocznij nagrywanie</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcję</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Rozmaż</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mozaika</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Włącz dźwięk</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>System audio</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Wyłącz dźwięk</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Pokaż naciśnięcie klawisza</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Ukryj naciśnięcie klawisza</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Włącz kamerę</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Wyłącz kamerę</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Pokaż kliknięcie</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcję</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Prostokąt</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linia</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Strzałka</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Ołówek</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Zapisz do</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Pulpit</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Zdjęcia</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Folder</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Schowek</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Pokaż wskaźnik</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Nagrania</translation>
    </message>
</context>
</TS>
